#!/bin/bash

# MonetDB fails to directly load the compressed file with
# "Failed to import table 'data-x', incomplete record at end of file"
test -s data.csv \
|| bzip2 -dc data.csv.bz2 > data.csv \
|| xz    -dc data.csv.xz  > data.csv \
|| gzip  -dc data.csv.gz  > data.csv

DBfarm="$PWD/DBfarm"
DBname="DBname"
DBport="50505"

monetdbd create "$DBfarm"
monetdbd set port="$DBport" "$DBfarm"
monetdbd start "$DBfarm"

monetdb -p"$DBport" stop "$DBname"
monetdb -p"$DBport" destroy "$DBname"
monetdb -p"$DBport" create "$DBname"
monetdb -p"$DBport" release "$DBname"
monetdb -p"$DBport" start "$DBname"


{
	cat create.sql
	cat <<- EOF
		start transaction;
		COPY OFFSET 3 INTO "data" FROM '$PWD/data.csv' DELIMITERS ',','\r\n','' NULL AS '';
		select 'csv',count(*) from "data";
		delete from "data";
		rollback;
		start transaction;
		COPY OFFSET 3 INTO "data" FROM '$PWD/data.csv.bz2' DELIMITERS ',','\r\n','' NULL AS '';
		select 'bz2',count(*) from "data";
		delete from "data";
		rollback;
		start transaction;
		COPY OFFSET 3 INTO "data" FROM '$PWD/data.csv.xz' DELIMITERS ',','\r\n','' NULL AS '';
		select 'xz',count(*) from "data";
		delete from "data";
		rollback;
		start transaction;
		COPY OFFSET 3 INTO "data" FROM '$PWD/data.csv.gz' DELIMITERS ',','\r\n','' NULL AS '';
		select 'gz',count(*) from "data";
		delete from "data";
		rollback;
		start transaction;
		COPY OFFSET 3 INTO "data" FROM '$PWD/data.csv' DELIMITERS ',','\r\n','' NULL AS '';
		select 'csv',count(*) from "data";
		delete from "data";
		rollback;
	EOF
} \
| mclient -p"$DBport" -d"$DBname"

monetdb -p"$DBport" stop "$DBname"

monetdbd stop "$DBfarm"
